@@ -8,3 +8,9 @@ class DropdownItem:
         self.value = value
         self.label = label or str(value or '')
         self.context = context or {}
+
+    def __eq__(self, o: object) -> bool:
+        return self.value == o.value and self.label == o.label
+
+    def __hash__(self) -> int:
+        return hash((self.value, self.label))
